/*
 * Example for Mic click
 *
 * Date         Mar 2017
 * Author       Djordje Rosic
 * Copyright    GNU Public License v2
 *
 * Test configuration dsPIC :
 *  MCU           :        P33FJ256GP710A
 *  Dev. Board    :        EasyPIC Fusion v7
 *  SW            :        mikroC PRO for dsPIC v7.0.1
 *
 ******************************************************************************/
#include <stdint.h>
#include "tft_resources.h"

sbit AN         at RB8_bit;        /*mic click AN pin settings*/
sbit AN_DIR     at TRISB8_bit;



uint16_t x;
uint16_t y;
uint16_t oldx;
uint16_t oldy;



static void systemInit( void );
/*
 * System Initialization
 */
void systemInit ()
{

    CLKDIVbits.PLLPRE = 0;   // PLLPRE<4:0> = 0  ->  N1 = 2    8MHz / 2 = 4MHz
                             // (must be within 0.8 MHz to 8 MHz range)
    PLLFBD =   38;           // PLLDIV<8:0> = 38 ->  M = 40    4MHz * 40 = 160MHz
                             // (must be within 100 MHz to 200 MHz range)
    CLKDIVbits.PLLPOST = 0;  // PLLPOST<1:0> = 0 ->  N2 = 2    160MHz / 2 = 80MHz
                             // (must be within 12.5 MHz to 80 MHz range)

    AN_DIR = 1;               /* Configure RB8/AN as input.  */
    
    x = 1;
    oldx = 0;
    oldy = 144;
    
    displayInit();
}

void main() 
{
    uint16_t valueMeasured;
    systemInit ();
    TFT_Set_Pen( CL_RED, 1 );
    while (1)
    {
        valueMeasured = ADC1_Read(8);

        y=valueMeasured/7 + 71;
        if (x !=0)
            TFT_Line (x, y, oldx, oldy);
        oldx = x;
        oldy = y;
        Delay_ms (10);
        x++;
        if (x==320)
        {
            x=0;  
            TFT_Set_Pen( CL_WHITE, 1 );
            TFT_Rectangle (0,71,320,219);
            TFT_Set_Pen( CL_RED, 1 );
        }
    }
}
/************************************************************ END OF FILE *****/